@@ -77,10 +77,13 @@ def corrFFT1(Img1, Img2):
             y_1[j,i] = (box_origin_y_1[j,i]-1+box_size_y/2)
 
             # Define sub images to work
-            SubImg1 = (Img1[int(box_origin_y_1[j,i]):int(box_origin_y_1[j,i])+box_size_y,
-                int(box_origin_x_1[j,i]):int(box_origin_x_1[j,i])+box_size_x])
-            SubImg2 = (Img2[int(box_origin_y_1[j,i]):int(box_origin_y_1[j,i])+box_size_y,
-                int(box_origin_x_1[j,i]):int(box_origin_x_1[j,i])+box_size_x])
+            box_o_y = int(box_origin_y_1[j,i])
+            box_o_x = int(box_origin_x_1[j,i])
+
+            SubImg1 = (Img1[box_o_y : box_o_y + box_size_y,
+                box_o_x : box_o_x + box_size_x])
+            SubImg2 = (Img2[box_o_y : box_o_y + box_size_y,
+                box_o_x : box_o_x + box_size_x])
 
             # Mask intensity changed to unmasked mean intensity
             if Parameters.mask:
@@ -319,10 +322,15 @@ def corrFFT2(Img1, Img2, x_1, y_1, u_1, v_1):
 # FIND PEAKS POSITION ON CORRELATION FUNCTION
 def find_peaks(correlation, box_size_x, box_size_y, window_x, window_y):
 
+    # Indices of searching windows
+    ini_cor_y = int(np.round(box_size_y/2-window_y/2))
+    end_cor_y = int(np.round(box_size_y/2+window_y/2+1))
+    ini_cor_x = int(np.round(box_size_x/2-window_x/2))
+    end_cor_x = int(np.round(box_size_x/2+window_x/2+1))
+
     # Find first peak
-    maxcor1 = (np.amax(
-        correlation[int(np.round(box_size_y/2-window_y/2)):int(np.round(box_size_y/2+window_y/2+1)),
-        int(np.round(box_size_x/2-window_x/2)):int(np.round(box_size_x/2+window_x/2+1))]))
+    maxcor1 = (np.amax(correlation[ini_cor_y : end_cor_y,
+        ini_cor_x:end_cor_x]))
     max_row1, max_col1 = np.where(correlation == maxcor1)
     max_row1 = max_row1[0].astype(int)
     max_col1 = max_col1[0].astype(int)
@@ -340,9 +348,8 @@ def find_peaks(correlation, box_size_x, box_size_y, window_x, window_y):
     correlation_z[max_col1-lm:max_col1+lm+1,max_row1-lm:max_row1+lm+1] = 0
 
     # Find second peak
-    maxcor2 = (np.amax(
-        correlation_z[int(np.round(box_size_y/2-window_y/2)):int(np.round(box_size_y/2+window_y/2+1)),
-        int(np.round(box_size_x/2-window_x/2)):int(np.round(box_size_x/2+window_x/2+1))]))
+    maxcor2 = (np.amax(correlation_z[ini_cor_y : end_cor_y,
+        ini_cor_x:end_cor_x]))
     max_row2, max_col2 = np.where(correlation_z == maxcor2)
     max_row2 = max_row2[0].astype(int)
     max_col2 = max_col2[0].astype(int)
@@ -367,16 +374,18 @@ def find_peaks(correlation, box_size_x, box_size_y, window_x, window_y):
 
 
     # If sum_cor_1/(sum_cor_2+1e-10) > Parameters.peak_ratio:
-    if maxcor2/(maxcor1+1e-10) > Parameters.peak_ratio or not len(fit_peak):
-        fit_peak = np.zeros([3,3])
+    if (maxcor2/(maxcor1+1e-10) > Parameters.peak_ratio
+            or fit_peak.shape != (3,3)):
 
+        fit_peak = np.zeros([3,3])
 
     # Define weighting functions
     [weight_i, weight_j] = np.meshgrid(np.arange(-1,2),np.arange(-1,2))
 
     # Bias correction based on westerweel
-    fit_peak = (np.divide(np.divide(fit_peak,1-np.abs(max_row-box_size_y/2 +
-        weight_j)/box_size_y),1-np.abs(max_col-box_size_x/2+weight_i)/box_size_x))
+    fit_peak = (np.divide(np.divide(
+        fit_peak,1-np.abs(max_row-box_size_y/2 + weight_j)/box_size_y),
+        1-np.abs(max_col-box_size_x/2+weight_i)/box_size_x))
     fit_peak[np.where(fit_peak<0.001)] = 0.001
 
 
@@ -385,10 +394,20 @@ def find_peaks(correlation, box_size_x, box_size_y, window_x, window_y):
         epsilon_x = 0
         max_col = box_size_x//2
     else:
-        if (fit_peak[1,0]>0 and fit_peak[1,1]>0 and fit_peak[1,2]>0 and
-                (np.log(fit_peak[1,0])+np.log(fit_peak[1,2])-2*np.log(fit_peak[1,1])) != 0):
-            epsilon_x = (0.5*(np.log(fit_peak[1,0])-np.log(fit_peak[1,2]))
-                    /(np.log(fit_peak[1,0])+np.log(fit_peak[1,2])-2*np.log(fit_peak[1,1])))
+        if ( fit_peak[1, 0] > 0 and
+             fit_peak[1, 1] > 0 and
+             fit_peak[1, 2] > 0 and
+             (np.log(fit_peak[1,0]) +
+              np.log(fit_peak[1,2]) -
+              2*np.log(fit_peak[1,1])
+             ) != 0):
+
+            epsilon_x = (0.5*(np.log(fit_peak[1, 0]) -
+                              np.log(fit_peak[1,2])) /
+                         (np.log(fit_peak[1, 0]) +
+                          np.log(fit_peak[1, 2]) -
+                          2*np.log(fit_peak[1,1]))
+                        )
         else:
             epsilon_x = 0
 
@@ -396,10 +415,20 @@ def find_peaks(correlation, box_size_x, box_size_y, window_x, window_y):
         epsilon_y = 0
         max_row = box_size_y//2
     else:
-        if (fit_peak[0,1]>0 and fit_peak[1,1]>0 and fit_peak[2,1]>0 and
-                (np.log(fit_peak[0,1])+np.log(fit_peak[2,1])-2*np.log(fit_peak[1,1])) != 0):
-            epsilon_y = (0.5*(np.log(fit_peak[0,1])-np.log(fit_peak[2,1]))
-                    /(np.log(fit_peak[0,1])+np.log(fit_peak[2,1])-2*np.log(fit_peak[1,1])))
+        if ( fit_peak[0, 1] > 0 and
+             fit_peak[1, 1] > 0 and
+             fit_peak[2, 1] > 0 and
+             ( np.log(fit_peak[0, 1]) +
+               np.log(fit_peak[2, 1]) -
+               2*np.log(fit_peak[1, 1])
+             ) != 0):
+
+            epsilon_y = (0.5*(np.log(fit_peak[0,1]) -
+                              np.log(fit_peak[2,1])) /
+                         (np.log(fit_peak[0, 1]) +
+                          np.log(fit_peak[2, 1]) -
+                          2*np.log(fit_peak[1,1]))
+                        )
         else:
             epsilon_y = 0
 
@@ -494,7 +523,8 @@ def median_filter(u,v,limit):
             change_u,(v_median-v[j,1:num_col-1]))
     err_vect = err_vect+np.sum(change_u)
 
-    # Change the outlier vectors on the upper row using with 6-neighbors medians
+    # Change the outlier vectors on the upper row using with
+    # 6-neighbors medians
     j=num_row-1
     u_neigh[0,:] = u[j-1,0:num_col-2]
     u_neigh[1,:] = u[j-1,1:num_col-1]
@@ -604,6 +634,7 @@ def median_filter(u,v,limit):
     v_median = np.median([v[0,0], v[0,1], v[1,0], v[1,1]])
     median_magnitude = np.sqrt(u_median*u_median + v_median*v_median)
     delta_u = np.sqrt((u[0,0]-u_median)**2 +(v[0,0]-v_median)**2)
+
     if delta_u>median_magnitude*limit:
         uf[0,0] = u_median
         vf[0,0] = v_median
@@ -704,7 +735,7 @@ def jacobian_matrix(u, v, x, y, no_box_x, no_box_y):
     dv_dx[:,no_box_x-1] = (v[:,no_box_x-1]-v[:,no_box_x-2])/delta_x
 
     # Convolution of the image
-    k = 1/9*np.ones([3,3])  #convolution Kernel
+    k = 1/9*np.ones([3,3])  # Convolution Kernel
     du_dx = cv2.filter2D(du_dx,-1,k,borderType=cv2.BORDER_CONSTANT)
     du_dy = cv2.filter2D(du_dy,-1,k,borderType=cv2.BORDER_CONSTANT)
     dv_dx = cv2.filter2D(dv_dx,-1,k,borderType=cv2.BORDER_CONSTANT)
@@ -790,9 +821,12 @@ def deform_image(Img1, Img2, Width, Height, box_origin_x, box_origin_y,
             (dv_dx[j,i]+dv_dy[j,i])*np.ones([box_size_y,box_size_x]))
 
 
-    # Position of translated pixels of images 1 and 2 according to velocity field
-    [i_frac_1,j_frac_1,i_frac_2,j_frac_2,j_index_1,i_index_1,j_index_2,i_index_2] = translated_pixels(
-            i_index, j_index, u_index, v_index, Width,Height, box_size_x, box_size_y)
+    # Position of translated pixels of images 1 and 2 according to
+    # velocity field
+    [i_frac_1, j_frac_1, i_frac_2, j_frac_2, j_index_1,
+            i_index_1, j_index_2,i_index_2] = translated_pixels(
+            i_index, j_index, u_index, v_index, Width,Height,
+            box_size_x, box_size_y)
 
     # Define sub_image1 deformed according to velocity field
     SubImg1 = (np.multiply(np.multiply(1-j_frac_1,1-i_frac_1),
@@ -867,10 +901,10 @@ def load_images(name_img_1, name_img_2):
     any value to be 0 outside the mask.
     """
 
-    Img1 = 0.1 + np.asarray(cv2.cvtColor(cv2.imread(name_img_1),
+    Img1 = 0.001 + np.asarray(cv2.cvtColor(cv2.imread(name_img_1),
         cv2.COLOR_BGR2GRAY)).astype(np.float32)
 
-    Img2 = 0.1 + np.asarray(cv2.cvtColor(cv2.imread(name_img_2),
+    Img2 = 0.001 + np.asarray(cv2.cvtColor(cv2.imread(name_img_2),
         cv2.COLOR_BGR2GRAY)).astype(np.float32)
 
     return Img1, Img2
